@@ -11,9 +11,11 @@ import qualified GI.Cairo.Config as Cairo
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "Gdk"
         version = "3.0"
+        pkgName = "gi-gdk"
+        pkgVersion = "3.0.25"
         overridesFile = Just "Gdk.overrides"
         verbose = False
         outputDir = Nothing
